@@ -77,7 +77,7 @@ class DataClassMeta(type):
         options = dict(mcs.DEFAULT_OPTIONS)
 
         # record all functions defined by the user up through the inheritance chain
-        all_attrs = {a for b in bases for a in dir(b) if is_user_func(getattr(b, a))} | dict_.keys()
+        all_attrs = {a for b in bases for a in dir(b) if is_user_func(getattr(b, a, None))} | dict_.keys()
 
         dataclass_bases = [vars(b) for b in bases if hasattr(b, '__dataclass__')]
         for b in dataclass_bases + [dict_]:
@@ -114,9 +114,6 @@ class DataClassMeta(type):
         if options['init'] and all_annotations and '__init__' not in all_attrs:
             dict_.setdefault('__init__', generate_init(all_annotations, all_defaults, post_init,
                                                        options['kwargs'], options['frozen']))
-        elif options['init'] and '__init__' not in dict_ and '__post_init__' in dict_:
-            # if no fields to set, alias __post_init__ to __post_init__ so it is always called (unless init=False)
-            dict_['__init__'] = dict_['__post_init__']
 
         if options['repr']:
             '__repr__' in all_attrs or dict_.setdefault('__repr__', __repr__)
